..
    Copyright (C) 2020 Technische Universität Graz.

    invenio-rdm-pure is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Changes
=======

Version v0.1.2 (release 2023-01-16)

- fix: missing exports


Version v0.1.1 (release 2023-01-11)

- setup: remove translation config


Version v0.1.0 (release 2023-01-11)




Version 0.1.0 (released TBD)

- Initial public release.
